@@ -4,7 +4,7 @@ use warnings;
 BEGIN { eval "package HTTPEx; sub dummy {} 1;" }
 use base 'HTTPEx';
 use Class::Component;
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 use Carp;
 use Scalar::Util;
@@ -27,7 +27,7 @@ sub new {
     return $self;
 }
 
-sub run { die "404 Engine not found!" }
+sub run { croak ref($_[0] || $_[0] ) ." did not override HTTP::Engine::run" }
 
 sub set_handle_request {
     my($self, $callback) = @_;
@@ -72,9 +72,14 @@ sub handle_request {
         $self->$method($context);
     }
 
+    $self->run_hook( before_handle_request => $context );
     my $ret = eval {
         $self->{handle_request}->($context);
     };
+    {
+        local $@;
+        $self->run_hook( after_handle_request => $context );
+    }
     if (my $e = $@) {
         $self->push_errors($e);
         $self->run_hook('handle_error', $context);
@@ -100,9 +105,11 @@ sub finalize_headers {
     if (my $location = $c->res->redirect ) {
         $self->log( debug => qq/Redirecting to "$location"/ );
         $c->res->header( Location => $self->absolute_url($c, $location) );
+        $c->res->body($c->res->status . ': Redirect') unless $c->res->body;
     }
 
     # Content-Length
+    $c->res->content_length(0);
     if ($c->res->body && !$c->res->content_length) {
         # get the length from a filehandle
 	if (Scalar::Util::blessed($c->res->body) && $c->res->body->can('read')) {
@@ -116,6 +123,8 @@ sub finalize_headers {
         }
     }
 
+    $c->res->content_type('text/html') unless $c->res->content_type;
+
     # Errors
     if ($c->res->status =~ /^(1\d\d|[23]04)$/) {
         $c->res->headers->remove_header("Content-Length");
@@ -176,42 +185,48 @@ HTTP::Engine - Web Server Gateway Interface and HTTP Server Engine Drivers (Yet
 
 =head1 CONCEPT RELEASE
 
-Version 0.0.x is Concept release, An internal interface is chiefly fluid. 
-It is chiefly based on the code of Catalyst::Engine.
+Version 0.0.x is a concept release, the internal interface is still fluid. 
+It is mostly based on the code of Catalyst::Engine.
 
 =head1 DESCRIPTION
 
-HTTP::Engine is a bare-bones, extensible HTTP engine. Not, it's not a 
-socket binding server. Its purpose is to be an adaptor to various HTTP
-based logic layers and the actual implementation of an HTTP server,
-for example, mod_perl and FastCGI
+HTTP::Engine is a bare-bones, extensible HTTP engine. It is not a 
+socket binding server. The purpose of this module is to be an 
+adaptor between various HTTP-based logic layers and the actual 
+implementation of an HTTP server, such as, mod_perl and FastCGI
 
 =head1 PLUGINS
 
-For all non-core plugins (consult at #codrepos first), use the HTTPEx::
+For all non-core plugins (consult #codrepos first), use the HTTPEx::
 namespace. For example, if you have a plugin module named "HTTPEx::Plugin::Foo",
-you should load it as
+you could load it as
 
   use HTTP::Engine;
-  HTTP::Engnie->load_plugins(qw( +HTTPEx::Plugin::Foo ));
+  HTTP::Engine->load_plugins(qw( +HTTPEx::Plugin::Foo ));
 
 =head1 AUTHOR
 
 Kazuhiro Osawa E<lt>ko@yappo.ne.jpE<gt>
 
-=head1 COMMITTERS
-
 lestrrat
 
 tokuhirom
 
+nyarla
+
+marcus
+
 =head1 SEE ALSO
 
+wiki page L<http://coderepos.org/share/wiki/HTTP%3A%3AEngine>
+
+L<Class::Component>
+
 =head1 REPOSITORY
 
   svn co http://svn.coderepos.org/share/lang/perl/HTTP-Engine/trunk HTTP-Engine
 
-HTTP::Engine is Subversion repository is hosted at L<http://coderepos.org/share/>.
+HTTP::Engine's Subversion repository is hosted at L<http://coderepos.org/share/>.
 patches and collaborators are welcome.
 
 =head1 LICENSE
