@@ -1,4 +1,4 @@
-package HTTP::Engine::Plugin::KCatch;
+package HTTP::Engine::Plugin::DebugScreen;
 use strict;
 use warnings;
 use base qw( HTTP::Engine::Plugin );
@@ -7,6 +7,7 @@ use Carp::Always;
 sub handle_error:Hook {
     my ( $self, $engine, $context) = @_;
     $context->res->code( 500 );
+    $context->res->content_type( 'text/plain' );
     $context->res->body( join("\n", @{ $engine->errors }) );
 }
 
